# Keyword multiple select enhancement test - refs PLIP ticket #11017.

The PLIP adds an accessible, jQuery-based widget, which includes both a scrollbar and checkboxes.

This file is basically a copy of ../keyword.pt, with QUnit added, and slight modifications to make it run in a static, standalone way, looking somewhat realistic, although Plone's css messes up QUnit's a little.

---

## QUnit Test Suite

##

##

---

## Manual Test

dl semantically associates selector name with values

Select from existing tags.
Use Control/Command/Shift keys to select multiple tags. Type-to-skip functionality with javascipt enabled currently is described as "Hover and type the first letter to skip through tags." However, on touch-driven devices, vertical hover typically scrolls the page, so horizontal hover is necessary to enable this. Alternatively, clicking any of the tags also enables type-to-skip. So the text could technically be extended to handle this special case as "Hover or click and type the first letter to skip through tags.", but I think this would be confusing to the majority of users.
These spans are hidden by css, and used by the JavaScript called below. No tags currently selected. % tags currently selected. Call js to modify this widget with both a scrollbar and checkboxes. There may be a better place to put this js call; examples exist in others' widget.py and js files, but having it here covers cases where some but not all select elements call js to be modified. Todo: The #subject should eventually refer to the template variable.
An existing tag

Create and apply new tags.
Enter one tag per line, multiple words allowed.
  A new tag